pub struct TikTokData {
client: Client,
encoder_task: EncoderTask,
pub post_page_cache: TimedCache<String, Post>,
video_download_cache_path: Utf8PathBuf,
video_download_request_map: Arc<RequestMap<String, Result<Arc<Utf8Path>, ArcAnyhowError>>>,
video_encoder: &'static str,
}Expand description
TikTok Data
Fields
client: ClientThe inner client
encoder_task: EncoderTaskThe encoder task
post_page_cache: TimedCache<String, Post>A cache of post urls => post pages
video_download_cache_path: Utf8PathBufThe path to tiktok’s cache dir
video_download_request_map: Arc<RequestMap<String, Result<Arc<Utf8Path>, ArcAnyhowError>>>The request map for making requests for video downloads.
video_encoder: &'static strImplementations
Sourceimpl TikTokData
impl TikTokData
Sourcepub async fn new<P>(cache_dir: P, encoder_task: EncoderTask) -> Result<Self>where
P: AsRef<Utf8Path>,
pub async fn new<P>(cache_dir: P, encoder_task: EncoderTask) -> Result<Self>where
P: AsRef<Utf8Path>,
Make a new TikTokData.
Sourcepub async fn get_post_cached(
&self,
url: &str,
) -> Result<Arc<TimedCacheEntry<Post>>>
pub async fn get_post_cached( &self, url: &str, ) -> Result<Arc<TimedCacheEntry<Post>>>
Get a post page, using the cache if needed
Sourcepub async fn get_video_data_cached(
&self,
id: u64,
format: &str,
url: &str,
video_duration: u64,
) -> Result<Arc<Utf8Path>>
pub async fn get_video_data_cached( &self, id: u64, format: &str, url: &str, video_duration: u64, ) -> Result<Arc<Utf8Path>>
Get video data, using the cache if needed
Sourcepub async fn try_embed_url(
&self,
ctx: &Context,
msg: &Message,
url: &Url,
loading_reaction: &mut Option<LoadingReaction>,
delete_link: bool,
) -> Result<()>
pub async fn try_embed_url( &self, ctx: &Context, msg: &Message, url: &Url, loading_reaction: &mut Option<LoadingReaction>, delete_link: bool, ) -> Result<()>
Try embedding a url